@@ -26,12 +26,12 @@
 
 This AWS Solutions Construct implements an Amazon SQS queue connected to an AWS Lambda function.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescipr:
 
 ```javascript
-const { SqsToLambda } = require('@aws-solutions-constructs/aws-sqs-lambda');
+import { SqsToLambda, SqsToLambdaProps } from "@aws-solutions-constructs/aws-sqs-lambda";
 
-new SqsToLambda(stack, 'SqsToLambdaPattern', {
+new SqsToLambda(this, 'SqsToLambdaPattern', {
     lambdaFunctionProps: {
         runtime: lambda.Runtime.NODEJS_10_X,
         handler: 'index.handler',
@@ -87,6 +87,7 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
+* Enable X-Ray Tracing
 
 ## Architecture
 
@@ -104,8 +105,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -127,10 +128,10 @@ class SqsToLambda(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -167,17 +168,17 @@ class SqsToLambda(
 
         jsii.create(SqsToLambda, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
         return jsii.get(self, "lambdaFunction")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="sqsQueue")
     def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
         return jsii.get(self, "sqsQueue")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="deadLetterQueue")
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
         return jsii.get(self, "deadLetterQueue")
@@ -201,7 +202,7 @@ class SqsToLambdaProps:
         self,
         *,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
-        deploy_dead_letter_queue: typing.Optional[bool] = None,
+        deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -221,16 +222,12 @@ class SqsToLambdaProps:
         :summary:: The properties for the SqsToLambda class.
         """
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(
-                **dead_letter_queue_props
-            )
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        self._values = {}
+        self._values: typing.Dict[str, typing.Any] = {}
         if dead_letter_queue_props is not None:
             self._values["dead_letter_queue_props"] = dead_letter_queue_props
         if deploy_dead_letter_queue is not None:
@@ -253,16 +250,18 @@ class SqsToLambdaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("dead_letter_queue_props")
+        result = self._values.get("dead_letter_queue_props")
+        return result
 
     @builtins.property
-    def deploy_dead_letter_queue(self) -> typing.Optional[bool]:
+    def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
         """Whether to deploy a secondary queue to be used as a dead letter queue.
 
         default
         :default: - true.
         """
-        return self._values.get("deploy_dead_letter_queue")
+        result = self._values.get("deploy_dead_letter_queue")
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -271,7 +270,8 @@ class SqsToLambdaProps:
         default
         :default: - None
         """
-        return self._values.get("existing_lambda_obj")
+        result = self._values.get("existing_lambda_obj")
+        return result
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
@@ -280,7 +280,8 @@ class SqsToLambdaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("existing_queue_obj")
+        result = self._values.get("existing_queue_obj")
+        return result
 
     @builtins.property
     def lambda_function_props(
@@ -291,7 +292,8 @@ class SqsToLambdaProps:
         default
         :default: - Default properties are used.
         """
-        return self._values.get("lambda_function_props")
+        result = self._values.get("lambda_function_props")
+        return result
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -300,7 +302,8 @@ class SqsToLambdaProps:
         default
         :default: - required field if deployDeadLetterQueue=true.
         """
-        return self._values.get("max_receive_count")
+        result = self._values.get("max_receive_count")
+        return result
 
     @builtins.property
     def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -309,12 +312,13 @@ class SqsToLambdaProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("queue_props")
+        result = self._values.get("queue_props")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
